/*  -------------------------------------------------------------------------
    nfrancis.c version 1.0, written by Marco Bersani, Stradella, Italy,
    on August 2003; uses ncurses (requires a color terminal).

    Nfrancis is a program that calculates the main charachteristics of a
    francis turbine given the mechanical power output and the head.

    Report bugs to bermar2@inwind.it or mbers@libero.it

--------------------------------------------------------------------------
    Copyright 31-08-2003, Marco Bersani, bermar2@inwind.it or mbers@libero.it

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program (see the file COPYING which accompany
    this source file);  if not, write to the Free Software Foundation, Inc.,
    59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ----------------------------------------------------------------------- */

#include<stdio.h>
#include<stdlib.h>
#include<math.h>
#include<ncurses.h>


#define ITALIANO  0
#define ENGLISH   1


void nfrancis(void);
float empiric(float *a, float nc);
void collega_tabmessaggi(int language);
void stampa_about(void);
void stampa_licenza(void);

/* ######### TABELLE PER IL DIMENSIONAMENTO ############ */
float nct[9]={350.0,200.0,150.0,125.0,115.0,115.0,110.0,100.0,100.0};
float k1it[9]={0.64,0.67,0.70,0.71,0.71,0.71,0.71,0.70,0.68};
float k1et[9]={0.64,0.67,0.72,0.80,0.90,1.05,1.13,1.25,1.38};
float k2it[9]={0.33,0.35,0.36,0.36,0.37,0.38,0.40,0.40,0.41};
float k2et[9]={0.35,0.50,0.64,0.77,0.91,1.05,1.19,1.32,1.45};
float bd1t[9]={0.03,0.12,0.19,0.25,0.29,0.33,0.35,0.37,0.39};





/* ######### VETTORI DI CARATTERI PER I MESSAGGI ############ */

char *msg[43]; /* vettore di puntatori ai messaggi */


/* Messaggi in italiano - Messages in italian */
char msg_it_01[77]="***** DIMENSIONAMENTO DI UNA TURBINA FRANCIS ******";
char msg_it_02[77]="###      FINESTRA DI INPUT      ###";
char msg_it_03[77]="Potenza asse[MW][0.1;500](0=FINE): ";
char msg_it_04[77]="Salto motore [m] [50;450]        : ";
char msg_it_05[77]="## CARATTERISTICHE TECNICHE 2 ##";
char msg_it_06[77]="Potenza all'asse   P=";
char msg_it_07[77]="Salto motore      Hm=";
char msg_it_08[77]="rendim. volumetrico rv=";
char msg_it_09[77]="rendim. meccanico   rm=";
char msg_it_10[77]="rendim. idraulico   ri=";
char msg_it_11[77]="     ### CARATTERISTICHE TECNICHE  1 ###   ";
char msg_it_12[77]="Numero giri caratteristico  nc=";
char msg_it_13[77]="Portata ................... Q=";
char msg_it_14[77]="Velocita' di rotazione ..... n=";
char msg_it_15[77]="Diametro ingresso interno  D1i=";
char msg_it_16[77]="Diametro ingresso esterno  D1e=";
char msg_it_17[77]="Altezza della pala ......... b=";
char msg_it_18[77]="            ### TRIANGOLO DI VELOCITA' IN INGRESSO ###            ";
char msg_it_19[77]="Velocita' di trascinamento media in ingresso .. u1=";
char msg_it_20[77]="Angolo tra u1 e v1 ......................... alfa1=";
char msg_it_21[77]="Velocita' assoluta di ingresso ................ v1=";
char msg_it_22[77]="Angolo tra u1 e w1 ......................... beta1=";
char msg_it_23[77]="Velocita' relativa di ingresso ................ w1=";
char msg_it_24[77]="            ### TRIANGOLO DI VELOCITA' IN USCITA ###              ";
char msg_it_25[77]="Velocita' di trascinamento media allo scarico . u2=";
char msg_it_26[77]="Diametro medio uscita .... D2m=";
char msg_it_27[77]="Diametro uscita interno .. D2i=";
char msg_it_28[77]="Diametro uscita esterno .. D2e=";
char msg_it_29[77]="Velocita' assoluta di uscita .................. v2=";
char msg_it_30[77]="Velocita' relativa di uscita .................. w2=";
char msg_it_31[77]="Angolo tra u2 e w2 ......................... beta2=";
char msg_it_32[77]="TRIANGOLO DI VELOCITA'    "; /* gli spazi in coda sono necessari */
char msg_it_33[77]="IN INGRESSO               "; /* gli spazi in coda sono necessari */
char msg_it_34[77]="ALLO SCARICO              "; /* gli spazi in coda sono necessari */
char msg_it_35[77]="rendimento volumetrico  [0;1]: ";
char msg_it_36[77]="rendimento meccanico    [0;1]: ";
char msg_it_37[77]="rendimento idraulico    [0;1]: ";
char msg_it_38[77]="Dati in ingresso errati. Premi un tasto.";
char msg_it_39[77]="Grado di reazione... r=";
char msg_it_40[77]="Salto press.totale  pt=";
char msg_it_41[77]="Salto press.distrib pd=";
char msg_it_42[77]="Salto press.girante pg=";

/* Messaggi in inglese - Messages in english */
char msg_en_01[77]="    ***** CALCULATION OF A FRANCIS TURBINE ******    ";
char msg_en_02[77]="###         INPUT WINDOW        ###";
char msg_en_03[77]="Output power[MW][0.1;500](0=END): ";
char msg_en_04[77]="Head [m]         [50;450]       : ";
char msg_en_05[77]="# TECHNICAL CHARACTERISTICS 2 #";
char msg_en_06[77]="Power shaft output P=";
char msg_en_07[77]="Head              Hm=";
char msg_en_08[77]="volumetric efficiency rv=";
char msg_en_09[77]="mechanic  efficiency  rm=";
char msg_en_10[77]="hydraulic efficiency  ri=";
char msg_en_11[77]="   ### TECHNICAL CHARACHTERISTICS 1 ###    ";
char msg_en_12[77]="Specific speed ............ nc=";
char msg_en_13[77]="Flow rate ................. Q=";
char msg_en_14[77]="Rotation rate .............. n=";
char msg_en_15[77]="Impeller int. inlet diam.. D1i=";
char msg_en_16[77]="Impeller ext. inlet diam.. D1e=";
char msg_en_17[77]="Height of impeller blades .. b=";
char msg_en_18[77]="            ###          INLET VELOCITIES          ###            ";
char msg_en_19[77]="Inlet blade velocity .......................... u1=";
char msg_en_20[77]="Angle between u1 and v1 .................... alfa1=";
char msg_en_21[77]="Effective inlet fluid velocity ................ v1=";
char msg_en_22[77]="Angle between u1 and w1 (inlet blade angle). beta1=";
char msg_en_23[77]="Inlet fluid velocity relative to blade......... w1=";
char msg_en_24[77]="            ###         OUTLET VELOCITIES          ###            ";
char msg_en_25[77]="Outlet mean blade velocity .................... u2=";
char msg_en_26[77]="Impeller mean outlet diam. D2m=";
char msg_en_27[77]="Impeller int. outlet diam. D2i=";
char msg_en_28[77]="Impeller ext. outlet diam. D2e=";
char msg_en_29[77]="Effective outlet fluid velocity ............... v2=";
char msg_en_30[77]="Outlet fluid velocity relative to blade........ w2=";
char msg_en_31[77]="Angle between u2 and w2 (outlet blade angle) beta2=";
char msg_en_32[77]="VELOCITIES                "; /* spaces at the end of the string are necessaries */
char msg_en_33[77]="INLET                     "; /* spaces at the end of the string are necessaries */
char msg_en_34[77]="OUTLET                    "; /* spaces at the end of the string are necessaries */
char msg_en_35[77]="volumetric  efficiency [0;1]: ";
char msg_en_36[77]="mechanic  efficiency   [0;1]: ";
char msg_en_37[77]="hydraulic efficiency   [0;1]: ";
char msg_en_38[77]="Bad input data. Press any key.";
char msg_en_39[77]="Grade of reaction.. r=";
char msg_en_40[77]="Total press.drop  pt=";
char msg_en_41[77]="Distr. press.drop pd=";
char msg_en_42[77]="Impell.press.drop pg=";




int main()
{
char c;
/* ######### AVVIA NCURSES SUL TERMINALE A CARATTERI CORRENTE ############*/

initscr();

if(has_colors() == FALSE)                  /* Exit if terminal does not support color */
     {endwin();
      printf("Your terminal does not support color.\n");
      exit(1);}

start_color();
init_pair(1, COLOR_WHITE, COLOR_BLUE);
init_pair(2, COLOR_WHITE, COLOR_RED);
init_pair(3, COLOR_BLACK, COLOR_YELLOW);
bkgdset(COLOR_PAIR(1));
cbreak();






do  {
        /* ########### MENU DI AVVIO ############# */
        clear();
        noecho();
        attron(COLOR_PAIR(3));
        mvprintw(1,12,"NFRANCIS 1.0 text-only version Written by Marco Bersani");
        attroff(COLOR_PAIR(3));
        mvprintw(4,5,"GNU nfrancis, version 1.0. - Copyright (C) 2003 Marco Bersani");
        mvprintw(5,5,"This is free software; see the source code for copying conditions.");
        mvprintw(6,5,"There is ABSOLUTELY NO WARRANTY; not even for MERCHANTIBILITY or");
        mvprintw(7,5,"FITNESS FOR A PARTICULAR PURPOSE.  For details, see \"WARRANTY\".");
        mvprintw(8,5,"Report bugs to <bermar2@inwind.it>.");
        attron(COLOR_PAIR(2));
        mvprintw(11,24,"----------START MENU-----------");
        attroff(COLOR_PAIR(2));
        mvprintw(12,24,"1) START ITALIAN");
        mvprintw(13,24,"2) START ENGLISH");
        mvprintw(14,24,"3) ABOUT NFRANCIS");
        mvprintw(15,24,"4) WARRANTY");
        mvprintw(16,24,"5) QUIT");
        mvprintw(18,24,"CHOICE? (1-5)");
        refresh();

        c='0'; /* inizializza c */

        while(c!='1' && c!='2' && c!='3' && c!='4' && c!='5')
                                c=getch();



        if(c=='1')      {collega_tabmessaggi(ITALIANO);
                         nfrancis();}

        else if(c=='2') {collega_tabmessaggi(ENGLISH);
                         nfrancis();}

        else if(c=='3') stampa_about();

        else if(c=='4') stampa_licenza();


    }
while(c!='5');



echo();
endwin();

fprintf(stderr,"Program correctly terminated.\n");
return(0);
}












/* ####################### SOTTOPROGRAMMA DI CALCOLO ########################## */
void nfrancis(void)
{
char c;

/* ######### FINESTRE A CARATTERI DI NCURSES ########### */
WINDOW *ingr, *imp, *ris, *tvi, *tvu;

/* Variabili usate per il calcolo */
float p,q,n,hm,rv,rm,ri,psi,fi,nc;
float k1i,k1e,u1i,u1e,d1i,d1e,b,x;
float d1m,u1m,aux1,aux2,alfa1,alfa1deg,v1,beta1,beta1deg,w1;
float k2i,k2e,k2m,u2m,u2i,u2e,d2m,d2i,d2e,aux3,sezu,v2,w2,beta2,beta2deg;
float r,pg,pd,pt;

/* p  = potenza all'asse [MW]
   q  = portata [mc/s]
   n  = velocita' di rotazione [giri/min]
   hm = salto motore [m]
   rv, rm, ri = rendimenti volumetrico, meccanico, idraulico [adimensionali]
   psi = coefficiente di ingombro delle pale [adimensionale]
   fi  = coefficiente di non-monodimensionalita' del flusso
   k1i, k1e = coefficienti di velocita' periferica all'ingresso (interno,esterno)
   u1i, u1e = velocita' di trascinamento all'ingresso (interna, esterna) [m/s]
   d1i, d1e = diametri all'ingresso (interno, esterno) [m]
   b  = altezza della pala [m]
   d1m = diametro medio all'ingresso [m]
   u1m = velocita' di trascinamento media all' ingresso [m/s]
   v1 = velocita' dell'acqua in ingresso
   w1 = velocita' relativa dell'acqua in ingresso [m/s]
   alfa1 = angolo tra u1m e v1 in radianti
   alfa1deg = angolo tra u1m e v1 in gradi
   beta1 = angolo tra u1m e w1 in radianti
   beta1deg = angolo tra u1m e w1 in gradi
   r = grado di reazione */





do
 {
  clear();
  attron(COLOR_PAIR(3));
  /* stampa "***** DIMENSIONAMENTO DI UNA TURBINA FRANCIS ******" */
  mvprintw(0,13,"%s\n",msg[1]);
  attroff(COLOR_PAIR(3));
  refresh();

  ingr = newwin(8, 42, 2, 17);
  echo();

  do
  {wclear(ingr);
   wattron(ingr,COLOR_PAIR(2));
   wprintw(ingr,"%s\n",msg[2]); /* stampa "###    FINESTRA DI INPUT    ###" */
   wattroff(ingr,COLOR_PAIR(2));

   wprintw(ingr,"%s",msg[3]);   /* stampa "Potenza asse [MW] [0.1-500](0=FINE): " */
   wrefresh(ingr);
   wscanw(ingr,"%f",&p);}
  while((p<0.1 && p!=0) || p>500);

  noecho();


  if(p!=0)
   {
    do
    {echo();
     wprintw(ingr,"%s",msg[4]); /* stampa "Salto motore [m] [50;450]         : " */
     wrefresh(ingr);
     wscanw(ingr,"%f",&hm);
     wprintw(ingr,"%s",msg[35]); /* stampa "Rendim. volumetrico [0;1]: " */
     wrefresh(ingr);
     wscanw(ingr,"%f",&rv);
     wprintw(ingr,"%s",msg[36]); /* stampa "Rendim. meccanico   [0;1]: " */
     wrefresh(ingr);
     wscanw(ingr,"%f",&rm);
     wprintw(ingr,"%s",msg[37]); /* stampa "Rendim. idraulico   [0;1]: " */
     wrefresh(ingr);
     wscanw(ingr,"%f",&ri);
     noecho();

     if(hm<50 || hm>450 || rv<0 || rv>1 || rm<0 || rm>1 || ri<0 || ri>1)
       {
        wattron(ingr,COLOR_PAIR(3));
        wprintw(ingr,"%s",msg[38]); /* Stampa "Bad input data. Press any key." */
        wattroff(ingr,COLOR_PAIR(3));
        wrefresh(ingr);
        c=getch();
        wclear(ingr);
        wattron(ingr,COLOR_PAIR(2));
        wprintw(ingr,"%s\n",msg[2]); /* stampa "###    FINESTRA DI INPUT    ###" */
        wattroff(ingr,COLOR_PAIR(2));
        wprintw(ingr,"%s%3.1f\n",msg[3],p);   /* stampa "Potenza asse [MW] [0.1-500](0=FINE): " */
       }
     }
     while(hm<50 || hm>450 || rv<0 || rv>1 || rm<0 || rm>1 || ri<0 || ri>1);


    delwin(ingr);
    clear();
    refresh();


    psi=0.96; /* ingombro delle pale */
    fi=0.95;  /* non-monodimensionalita' del flusso */







    clear();
    attron(COLOR_PAIR(3));
    /* stampa "***** DIMENSIONAMENTO DI UNA TURBINA FRANCIS ******" */
    mvprintw(0,13,"%s\n",msg[1]);
    attroff(COLOR_PAIR(3));
    refresh();


    imp = newwin(10, 35, 1, 45);
    ris = newwin(10, 44, 1, 0);
    tvi = newwin(6, 67, 12, 0);
    tvu = newwin(5, 67, 19, 0);


    wclear(imp);
    wattron(imp,COLOR_PAIR(2));
    wprintw(imp,"%s\n",msg[5]); /* stampa "###     DATI DI CALCOLO     ###" */
    wattroff(imp,COLOR_PAIR(2));
    wprintw(imp,"%s %3.2f MW\n",msg[6],p);  /* stampa "Potenza all'asse   P=" */
    wprintw(imp,"%s %3.2f m\n",msg[7],hm);  /* stampa "Salto motore      Hm=" */
    wprintw(imp,"%s %3.2f\n",msg[8],rv);  /* stampa "rendim. volumetrico rv=" */
    wprintw(imp,"%s %3.2f\n",msg[9],rm);  /* stampa "rendim. meccanico   rm=" */
    wprintw(imp,"%s %3.2f\n",msg[10],ri);  /* stampa "rendim. idraulico   ri=" */


    wclear(ris);
    wattron(ris,COLOR_PAIR(2));
    wprintw(ris,"%s\n",msg[11]); /* stampa "     ### CARATTERISTICHE COSTRUTTIVE ###    " */
    wattroff(ris,COLOR_PAIR(2));

    nc=empiric(nct,hm);
    wprintw(ris,"%s %3.2f\n",msg[12],nc); /* stampa "Numero giri caratteristico  nc" */

    q=p*1000/(9.81*hm*ri*rv*rm);
    wprintw(ris,"%s %3.2f m3/s\n",msg[13],q);/* stampa "Portata .................... Q" */

    n=(sqrt(sqrt(hm*hm*hm))*nc)/(3.65*sqrt(q));
    wprintw(ris,"%s %3.2f RPM\n",msg[14],n); /* stampa "Velocita' di rotazione ..... n" */

    /* coefficienti di velocita' periferica in ingresso */
    k1i=empiric(k1it,nc);
    k1e=empiric(k1et,nc);

    /* velocita' di trascinamento in ingresso */
    u1i=k1i*sqrt(2*9.81*hm);
    u1e=k1e*sqrt(2*9.81*hm);

    /* diametri in ingresso */
    d1i=(60/3.14159)*(u1i/n);
    d1e=(60/3.14159)*(u1e/n);

    /* altezza della pala */
    x=empiric(bd1t,nc);
    b=d1e*x;

    wprintw(ris,"%s %3.2f m\n",msg[15],d1i); /* stampa "Diametro ingresso interno  D1i" */
    wprintw(ris,"%s %3.2f m\n",msg[16],d1e); /* stampa "Diametro ingresso esterno  D1e" */
    wprintw(ris,"%s %3.2f m\n",msg[17],b);   /* stampa "Altezza della pala ......... b" */




    /* TRIANGOLO DI VELOCITA' IN INGRESSO */
    wclear(tvi);
    wattron(tvi,COLOR_PAIR(2));
    wprintw(tvi,"%s\n",msg[18]); /* stampa "            ### TRIANGOLO DI VELOCITA' IN INGRESSO ###            " */
    wattroff(tvi,COLOR_PAIR(2));

    /* diametro medio in ingresso e velocita' di
       trascinamento media in ingresso */
    d1m=(d1i+d1e)/2;
    u1m=(u1i+u1e)/2;
    wprintw(tvi,"%s %3.2f m/s\n",msg[19],u1m); /* stampa "Velocita' di trascinamento media in ingresso .. u1" */

    aux1=(q*rv)/(3.14159*d1m*b*fi*psi);  /* v1*sen(alfa1) */
    aux2=(ri*9.81*hm)/u1m;               /* v1*cos(alfa1) */

    /* velocita' assoluta in ingresso */
    alfa1=atan(aux1/aux2);
    alfa1deg=alfa1*180/3.14159;
    v1=aux2*cos(alfa1);
    wprintw(tvi,"%s %3.2f deg\n",msg[20],alfa1deg); /* stampa "Angolo tra u1 e v1 ......................... alfa1" */
    wprintw(tvi,"%s %3.2f m/s\n",msg[21],v1);         /* stampa "Velocita' assoluta di ingresso ................ v1" */

    /* velocita' relativa in ingresso */
    w1=sqrt(u1m*u1m+v1*v1-2*u1m*v1*cos(alfa1));
    beta1=asin((v1/w1)*sin(alfa1));
    beta1deg=beta1*180/3.14159;
    wprintw(tvi,"%s %3.2f deg\n",msg[22],beta1deg); /* stampa "Angolo tra u1 e w1 ......................... beta1" */
    wprintw(tvi,"%s %3.2f m/s\n",msg[23],w1);         /* stampa "Velocita' relativa di ingresso ................ w1" */



    /* TRIANGOLO DI VELOCITA' IN USCITA e DIAMETRI IN USCITA (alla finestra RIS) */
    wclear(tvu);
    wattron(tvu,COLOR_PAIR(2));
    wprintw(tvu,"%s\n",msg[24]);      /* stampa "### TRIANGOLO DI VELOCITA' IN USCITA ###" */
    wattroff(tvu,COLOR_PAIR(2));

    k2i=empiric(k2it,nc);
    k2e=empiric(k2et,nc);

    k2m=(k2i+k2e)/2;
    aux3=sqrt(2*9.81*hm);
    u2m=k2m*aux3;
    wprintw(tvu,"%s %3.2f m/s\n",msg[25],u2m); /* stampa "Velocita' di trascinamento media allo scarico . u2" */

    d2m=(60/3.14159)*(u2m/n);
    wprintw(ris,"%s %3.2f m\n",msg[26],d2m); /* stampa "Diametro medio uscita .... D2m" */

    u2i=k2i*aux3;
    u2e=k2e*aux3;
    d2i=(60/3.14159)*(u2i/n);
    d2e=(60/3.14159)*(u2e/n);
    wprintw(ris,"%s %3.2f m\n",msg[27],d2i); /* stampa "Diametro uscita interno .. D2i" */
    wprintw(ris,"%s %3.2f m\n",msg[28],d2e);  /* stampa "Diametro uscita esterno .. D2e" */

    sezu=(3.14159/4)*d2e*d2e*psi;
    v2=q/sezu;       /* calcolo approx. con equaz. di continuita' */
    w2=sqrt(u2m*u2m+v2*v2);
    wprintw(tvu,"%s %3.2f m/s\n",msg[29],v2); /* stampa "Velocita' assoluta di uscita .................. v2" */
    wprintw(tvu,"%s %3.2f m/s\n",msg[30],w2); /* stampa "Velocita' relativa di uscita .................. w2" */

    beta2=atan(v2/u2m);
    beta2deg=beta2*180/3.14159;
    wprintw(tvu,"%s %3.2f deg\n",msg[31],beta2deg); /* stampa "Angolo tra u2 e w2 ......................... beta2" */

    /* GRADO DI REAZIONE */
    r=(((u1m*u1m-u2m*u2m)/(2*9.81))+((w2*w2-w1*w1)/(2*9.81)))/(hm/ri);

    pt=((hm/ri)*0.0981);
    pg=pt*r;
    pd=pt-pg;
    wprintw(imp,"%s %3.2f\n",msg[39],r);
    wprintw(imp,"%s %3.2f bar\n",msg[40],pt);
    wprintw(imp,"%s %3.2f bar\n",msg[41],pd);
    wprintw(imp,"%s %3.2f bar",msg[42],pg);


    wrefresh(imp);
    wrefresh(ris);
    wrefresh(tvi);
    wrefresh(tvu);


    
    getch();  /* waits for any key pressed */


    delwin(ris);
    delwin(tvi);
    delwin(tvu);
    delwin(imp);
    clear();
    refresh();
   }

   else {delwin(ingr);
         clear();
         refresh();}

 }while(p!=0);
}











/* interpola i dati tabulati per 50=<x<450 */
float empiric(float *y, float x)
{
int i;
float x1,res;

if((x>=50) && (x<450))   /* x compreso tra 50 (incluso) e 450 (escluso) */
 {i=(int)floor((x-50)/50);
  x1=(float)(i*50)+50;
  res=(x-x1)*(y[i+1]-y[i])/50+y[i];}

else
 res=-1;

return(res);
}








void collega_tabmessaggi(int language)
{
int i;
/*inizializza il vettore di indirizzi */
for(i=0;i<=39;i++)
         msg[i]=NULL;



switch(language)
 {
 case ITALIANO:
        msg[1]=msg_it_01;
        msg[2]=msg_it_02;
        msg[3]=msg_it_03;
        msg[4]=msg_it_04;
        msg[5]=msg_it_05;
        msg[6]=msg_it_06;
        msg[7]=msg_it_07;
        msg[8]=msg_it_08;
        msg[9]=msg_it_09;
        msg[10]=msg_it_10;
        msg[11]=msg_it_11;
        msg[12]=msg_it_12;
        msg[13]=msg_it_13;
        msg[14]=msg_it_14;
        msg[15]=msg_it_15;
        msg[16]=msg_it_16;
        msg[17]=msg_it_17;
        msg[18]=msg_it_18;
        msg[19]=msg_it_19;
        msg[20]=msg_it_20;
        msg[21]=msg_it_21;
        msg[22]=msg_it_22;
        msg[23]=msg_it_23;
        msg[24]=msg_it_24;
        msg[25]=msg_it_25;
        msg[26]=msg_it_26;
        msg[27]=msg_it_27;
        msg[28]=msg_it_28;
        msg[29]=msg_it_29;
        msg[30]=msg_it_30;
        msg[31]=msg_it_31;
        msg[32]=msg_it_32;
        msg[33]=msg_it_33;
        msg[34]=msg_it_34;
        msg[35]=msg_it_35;
        msg[36]=msg_it_36;
        msg[37]=msg_it_37;
        msg[38]=msg_it_38;
        msg[39]=msg_it_39;
        msg[40]=msg_it_40;
        msg[41]=msg_it_41;
        msg[42]=msg_it_42;
        break;


 case ENGLISH:
        msg[1]=msg_en_01;
        msg[2]=msg_en_02;
        msg[3]=msg_en_03;
        msg[4]=msg_en_04;
        msg[5]=msg_en_05;
        msg[6]=msg_en_06;
        msg[7]=msg_en_07;
        msg[8]=msg_en_08;
        msg[9]=msg_en_09;
        msg[10]=msg_en_10;
        msg[11]=msg_en_11;
        msg[12]=msg_en_12;
        msg[13]=msg_en_13;
        msg[14]=msg_en_14;
        msg[15]=msg_en_15;
        msg[16]=msg_en_16;
        msg[17]=msg_en_17;
        msg[18]=msg_en_18;
        msg[19]=msg_en_19;
        msg[20]=msg_en_20;
        msg[21]=msg_en_21;
        msg[22]=msg_en_22;
        msg[23]=msg_en_23;
        msg[24]=msg_en_24;
        msg[25]=msg_en_25;
        msg[26]=msg_en_26;
        msg[27]=msg_en_27;
        msg[28]=msg_en_28;
        msg[29]=msg_en_29;
        msg[30]=msg_en_30;
        msg[31]=msg_en_31;
        msg[32]=msg_en_32;
        msg[33]=msg_en_33;
        msg[34]=msg_en_34;
        msg[35]=msg_en_35;
        msg[36]=msg_en_36;
        msg[37]=msg_en_37;
        msg[38]=msg_en_38;
        msg[39]=msg_en_39;
        msg[40]=msg_en_40;
        msg[41]=msg_en_41;
        msg[42]=msg_en_42;
        break;

 }
}










void stampa_about(void)
{
 clear();
 attron(COLOR_PAIR(3));
 mvprintw(1,12,"       NFRANCIS 1.0 text-only version - ABOUT     ");
 attroff(COLOR_PAIR(3));

 mvprintw(4,5,"nfrancis.c versione 1.0, scritto da Marco Bersani, Stradella (PV), Italia,");
 mvprintw(5,5,"in agosto 2003, usa ncurses (richiede un terminale a colori).");
 mvprintw(6,5,"Nfrancis e' un programma che calcola le caratteristiche principali di una");
 mvprintw(7,5,"turbina francis dati la potenza meccanica all'asse e il salto motore.");
 mvprintw(8,5,"Per la geometria della turbina vedere l'immagine \"francis.jpg\" allegata.");
 mvprintw(9,5,"Riportare eventuali bug a bermar2@inwind.it oppure mbers@libero.it");
 mvprintw(10,5,"--------------------------------------------------------------------------");
 mvprintw(12,5,"nfrancis.c version 1.0, written by Marco Bersani, Stradella (PV), Italy,");
 mvprintw(13,5,"on August 2003; uses ncurses (requires a color terminal).");
 mvprintw(14,5,"Nfrancis is a program that calculates the main charachteristics of a");
 mvprintw(15,5,"francis turbine given the mechanical power output and the head.");
 mvprintw(16,5,"For turbine geometry see image \"francis.jpg\" in nfrancis package");
 mvprintw(17,5,"Report bugs to bermar2@inwind.it or mbers@libero.it");
 mvprintw(18,5,"--------------------------------------------------------------------------");
 mvprintw(22,25,"PRESS ANY KEY TO CONTINUE");
 refresh();
 getch();  /* waits for any key pressed */

}




void stampa_licenza(void)
{
  clear();
  attron(COLOR_PAIR(3));
  mvprintw(1,12,"       NFRANCIS 1.0 text-only version - WARRANTY    ");
  attroff(COLOR_PAIR(3));
  mvprintw(4,5,"GNU NFRANCIS, version 1.0.");
  mvprintw(5,5,"Copyright 2003 Marco Bersani, bermar2@inwind.it");
  mvprintw(7,5,"This program is free software; you can redistribute it and/or modify");
  mvprintw(8,5,"it under the terms of the GNU General Public License as published by");
  mvprintw(9,5,"the Free Software Foundation; either version 2 of the License, or");
  mvprintw(10,5,"(at your option) any later version.");
  mvprintw(12,5,"This program is distributed in the hope that it will be useful,");
  mvprintw(13,5,"but WITHOUT ANY WARRANTY; without even the implied warranty of");
  mvprintw(14,5,"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the");
  mvprintw(15,5,"GNU General Public License for more details.");
  mvprintw(17,5,"You should have received a copy of the GNU General Public License");
  mvprintw(18,5,"along with this program (see the file COPYING which accompany");
  mvprintw(19,5,"this source file);  if not, write to the Free Software Foundation, Inc.,");
  mvprintw(20,5,"59 Temple Place, Suite 330, Boston, MA  02111-1307  USA");
  mvprintw(22,25,"PRESS ANY KEY TO CONTINUE");
  refresh();
  getch();  /* waits for any key pressed */

}

